@@ -1,7 +1,7 @@
 from django_test_migrations.types import MigrationTarget
 
 
-class MigrationNotInPlan(Exception):
+class MigrationNotInPlan(Exception):  # noqa: N818
     """``MigrationTarget`` not found in migrations plan."""
 
     def __init__(self, migration_target: MigrationTarget) -> None:  # noqa: D107
@@ -9,6 +9,4 @@ class MigrationNotInPlan(Exception):
 
     def __str__(self) -> str:
         """String representation of exception's instance."""
-        return 'Migration {0} not found in migrations plan'.format(
-            self.migration_target,
-        )
+        return f'Migration {self.migration_target} not found in migrations plan'
